agentle.mcp.sampling.hint
=========================

.. automodule:: agentle.mcp.sampling.hint

   
   .. rubric:: Functions

   .. autosummary::
   
      Field
   
   .. rubric:: Classes

   .. autosummary::
   
      BaseModel
      Hint
   